Module client

Structs

Agent
A low level Agent to make calls to a Replica endpoint.
Client
Client for interacting with outside services (includes ICP and other blockchains)
ClientBuilder
Builder for creating a new Client with custom configuration

Traits

Identity
An Identity produces Signatures for requests or delegations. It knows or represents the Principal of the sender.

Functions

identity_from_pem
Loads an ICP identity from a PEM file (generated by dfx or other tools, supports both Ed25519 and Secp256k1)
identity_from_secret
Returns a new Ed25519 identity from a 32-byte secret
load_identity
Loads an identity from a 32-byte hex-encoded secret or PEM file